/**
 * Implement Gatsby's Browser APIs in this file.
 *
 * See: https://www.gatsbyjs.org/docs/browser-apis/
 */
require('./src/styles.css');
const { defaultPluginOptions } = require('./src/plugin-options');
const { setVisible, chatToggleCallback, setZIndex } = require('./src/actions');
const { createDismissButton, isDismissed } = require('./src/dismiss-button');
 
exports.onClientEntry = (_, options = {}) => {
  const pluginOptions = {
    ...defaultPluginOptions,
    ...options
  };

  if (window.adaEmbed) {
    window.adaEmbed.start({
      crossWindowPersistence: true,
      ...pluginOptions.adaSettings,
      toggleCallback: chatToggleCallback,
      handle: pluginOptions.handle,
      adaReadyCallback: () => {
        try {
          if (pluginOptions.dismissButton !== false) createDismissButton(pluginOptions);
          if (pluginOptions.zIndex) setZIndex(pluginOptions.zIndex);
          setTimeout(() => {
            if (!isDismissed(pluginOptions)) setVisible(true);
          }, pluginOptions.delay);
        } catch(e) {
          console.warn(`Failed to configure ADA chatbot: ${e}`);
        }
    }});
  }
};
