const { getAdaRoot } = require('./elements');
const { dismiss } = require('./actions');

const createDismissButton = (pluginOptions) => {
  try {
    const adaRoot = getAdaRoot();
    const button = document.createElement('button');
    button.classList.add('dismiss-ada-chatbot');
    button.addEventListener('click', () => dismiss(pluginOptions), true);
    button.tabIndex = 0;
    button.innerHTML = 'Dismiss';
    adaRoot.appendChild(button);
    return true;
  } catch(e) {
    return false;
  }
};

const isDismissed = (pluginOptions) => {
  try {
    const { dismissButton, dismissDuration } = pluginOptions;

    if (!dismissButton) return false;

    if (dismissDuration === 'session') {
      return !!sessionStorage.getItem('ada-chatbot-dismissed');
    } else if (typeof dismissDuration === 'number') {
      const expires = parseInt(localStorage.getItem('ada-chatbot-dismiss-expires') || '0', 10);
      if (Date.now() > expires) {
        localStorage.removeItem('ada-chatbot-dismissed');
        localStorage.removeItem('ada-chatbot-dismiss-expires');
      }
      return !!localStorage.getItem('ada-chatbot-dismissed');
    }

    return false;
  } catch(e) {
    return false;
  }
};

module.exports = {
  createDismissButton,
  isDismissed,
};
